# Automappy

A convention-based object-object mapper in Python.

Automappy is based on Python type hints and annotations to map objects from one type to another.

It is designed to be simple and easy to use, with a focus on convention over configuration.

## Contributing

Feel free to contribute to this project by opening a pull request.

## Issues

Feel free to open an issue if you have any questions or suggestions.

## Credits

Automappy is inspired by [AutoMapper](https://github.com/AutoMapper/AutoMapper/tree/master) from the .NET ecosystem.

## TODO

- [ ] Handle classes
- [ ] Mapper Configuration (allow to customize mappings)
- [ ] ReadTheDocs documentation
- [ ] Execution plan
  - Runnable execution tree
